==> haskell-mtl-2.2.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
key: mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 5531911f09693672654e6de645ce55e7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/mtl-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
depends:
    base-4.10.0.0 transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mtl-2.2.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
key: mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: a1f89647d7228db4bf59b7aaec52e888
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mtl-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
